Django-probes |latest-version|
==============================

|build-status| |python-support| |license|

This python package provides a management to check whether the database is ready

.. |latest-version| image:: https://img.shields.io/pypi/v/django-probes.svg
   :alt: Latest version on PyPI
   :target: https://pypi.org/project/django-probes
.. |build-status| image:: https://img.shields.io/travis/vshn/django-probes/master.svg
   :alt: Build status
   :target: https://travis-ci.org/vshn/django-probes
.. |python-support| image:: https://img.shields.io/pypi/pyversions/django-probes.svg
   :alt: Python versions
   :target: https://pypi.org/project/django-probes
.. |license| image:: https://img.shields.io/pypi/l/django-probes.svg
   :alt: Software license
   :target: https://github.com/vshn/django-probes/blob/master/LICENSE

Installation
============

The easiest way to install django-probes is with pip

.. code::

    $ pip install django-probes

Basic Usage
===========
